@@ -1,5 +1,4 @@
 #include <Rcpp.h>
-using namespace std;
 using namespace Rcpp;
 
 // calculates size of the ngram vector
@@ -8,7 +7,6 @@ inline  size_t get_ngram_seq_len(uint32_t input_len, uint32_t ngram_min, uint32_
   uint32_t out_ngram_len_adjust = 0;
   for (size_t i = ngram_min - 1; i < ngram_max; i++)
     out_ngram_len_adjust += i;
-
   if(input_len < ngram_min)
     return 0;
   else
@@ -18,40 +16,41 @@ inline  size_t get_ngram_seq_len(uint32_t input_len, uint32_t ngram_min, uint32_
 CharacterVector generate_ngrams_internal(const CharacterVector terms_raw,
                                 const uint32_t ngram_min,
                                 const uint32_t ngram_max,
-                                RCPP_UNORDERED_SET<string> &stopwords,
+                                RCPP_UNORDERED_SET<std::string> &stopwords,
                                 // pass buffer by reference to avoid memory allocation
                                 // on each iteration
-                                vector<string> &terms_filtered_buffer,
-                                const string ngram_delim) {
+                                std::vector<std::string> &terms_filtered_buffer,
+                                const std::string ngram_delim) {
   // clear buffer from previous iteration result
   terms_filtered_buffer.clear();
-  string term;
+  std::string term;
   // filter out stopwords
   for (auto it: terms_raw) {
-    term  = as<string>(it);
+    term  = as<std::string>(it);
     if(stopwords.find(term) == stopwords.end())
       terms_filtered_buffer.push_back(term);
   }
 
   uint32_t len = terms_filtered_buffer.size();
-  size_t ngram_out_len = get_ngram_seq_len(len, ngram_min, ngram_max);
+  size_t ngram_out_len = get_ngram_seq_len(len, ngram_min, std::min(ngram_max, len));
   CharacterVector result(ngram_out_len);
 
-  string k_gram;
+  std::string k_gram;
   size_t k, i = 0, j_max_observed;
   // iterates through input vector by window of size = n_max and build n-grams
-  // for terms ["a", "b", "c", "d"] and n_min = 1, n_max = 2
+  // for terms ["a", "b", "c", "d"] and n_min = 1, n_max = 3
   // will build 1:3-grams in following order
   //"a"     "a_b"   "a_b_c" "b"     "b_c"   "b_c_d" "c"     "c_d"   "d"
-  for(size_t j = 0; j < len; j ++ ) {
+  for(size_t j = 0; j < len; j++ ) {
     k = 1;
     j_max_observed = j;
     while (k <= ngram_max && j_max_observed < len) {
 
       if( k == 1) {
         k_gram = terms_filtered_buffer[j_max_observed];
-      } else
+      } else {
         k_gram = k_gram + ngram_delim + terms_filtered_buffer[j_max_observed];
+      }
 
       if(k >= ngram_min) {
         result[i] = k_gram;
@@ -71,15 +70,15 @@ ListOf<CharacterVector> generate_ngrams_batch(const ListOf<const CharacterVector
                                               const CharacterVector stopwords = CharacterVector(),
                                               const String ngram_delim = " ") {
 
-  vector<string> terms_filtered_buffer;
-  const string std_string_delim = ngram_delim.get_cstring();
+  std::vector<std::string> terms_filtered_buffer;
+  const std::string std_string_delim = ngram_delim.get_cstring();
   size_t n_docs = documents_list.size();
   List result(n_docs);
   CharacterVector terms;
 
-  RCPP_UNORDERED_SET<string> stopwords_set;
+  RCPP_UNORDERED_SET<std::string> stopwords_set;
   for(auto it:stopwords)
-    stopwords_set.insert(as<string>(it));
+    stopwords_set.insert(as<std::string>(it));
 
   for (size_t i_document = 0; i_document < n_docs; i_document++) {
     terms = documents_list[i_document];
